==> latte-dock-0.9.12.tar.xz: latte-dock-0.9.12/app/org.kde.latte-dock.desktop.cmake <==
[Desktop Entry]
Name=Latte
Name[ast]=Latte
Name[ca]=Latte
Name[ca@valencia]=Latte
Name[cs]=Latte
Name[da]=Latte
Name[de]=Latte
Name[el]=Latte
Name[en_GB]=Latte
Name[es]=Latte
Name[et]=Latte
Name[eu]=Latte
Name[fi]=Latte
Name[fr]=Latte
Name[gl]=Latte
Name[id]=Latte
Name[it]=Latte
Name[ko]=Latte
Name[nl]=Latte
Name[nn]=Latte
Name[pl]=Latte
Name[pt]=Latte
Name[pt_BR]=Latte
Name[ru]=Latte
Name[sk]=Latte
Name[sl]=Latte
Name[sv]=Latte
Name[uk]=Латте
Name[x-test]=xxLattexx
Name[zh_CN]=Latte
Name[zh_TW]=Latte
Comment=Dock for the masses
Comment[ca]=Acoblador per a les masses
Comment[ca@valencia]=Acoblador per a les masses
Comment[cs]=Dok pro masy
Comment[da]=Dok til masserene
Comment[de]=Dock für die Massen
Comment[el]=Πίνακες για όλον τον κόσμο
Comment[en_GB]=Dock for the masses
Comment[es]=Un dock para las masas
Comment[et]=Dokk massidele
Comment[eu]=Jendartearen kaia
Comment[fi]=Telakka massoille
Comment[fr]=Une barre des tâches pour tout le monde
Comment[gl]=Doca para as masas.
Comment[id]=Dock untuk mengumpulkan
Comment[it]=Area di aggancio per le masse
Comment[ko]=모두를 위한 독
Comment[nl]=Dock voor de massa
Comment[nn]=Dokk for massane
Comment[pl]=Dok dla mas
Comment[pt]=Área acoplável para as massas
Comment[pt_BR]=Área acoplável para todos
Comment[ru]=Док для всех
Comment[sk]=Dok pre davy ľudí
Comment[sl]=Dok za množice
Comment[sv]=Dockningsfönster för alla
Comment[uk]=Панель для усіх
Comment[x-test]=xxDock for the massesxx
Comment[zh_CN]=给大众使用的停靠栏
Comment[zh_TW]=給大眾使用的 Dock
GenericName=Dock
GenericName[ca]=Acobla
GenericName[ca@valencia]=Acobla
GenericName[cs]=Dok
GenericName[da]=Dok
GenericName[de]=Dock
GenericName[el]=Πίνακας
GenericName[en_GB]=Dock
GenericName[es]=Dock
GenericName[et]=Dokk
GenericName[eu]=Kaia
GenericName[fi]=Telakka
GenericName[fr]=Barre des tâches
GenericName[gl]=Doca
GenericName[id]=Dok
GenericName[it]=Aggancio
GenericName[ko]=독
GenericName[nl]=Dock
GenericName[nn]=Dokk
GenericName[pl]=Dok
GenericName[pt]=Área Acoplável
GenericName[pt_BR]=Área acoplável
GenericName[ru]=Док
GenericName[sk]=Dok
GenericName[sl]=Dok
GenericName[sv]=Dockningsfönster
GenericName[uk]=Панель
GenericName[x-test]=xxDockxx
GenericName[zh_CN]=停靠栏
GenericName[zh_TW]=Dock
Icon=latte-dock
Categories=Utility;X-SuSE-DesktopUtility;
Exec=@CMAKE_INSTALL_PREFIX@/bin/latte-dock
InitialPreference=1
StartupNotify=false
Terminal=false
Type=Application
StartupWMClass=latte-dock
X-DBUS-ServiceName=org.kde.lattedock
X-DBUS-StartupType=unique
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-StartupNotify=false
X-KDE-SubstituteUID=false
X-KDE-autostart-phase=1
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate

==> latte-dock-0.9.91.tar.xz: latte-dock-0.9.91/app/org.kde.latte-dock.desktop.cmake <==
[Desktop Entry]
Name=Latte
Name[az]=Latte
Name[ca]=Latte
Name[ca@valencia]=Latte
Name[cs]=Latte
Name[da]=Latte
Name[de]=Latte
Name[el]=Latte
Name[en_GB]=Latte
Name[es]=Latte
Name[et]=Latte
Name[eu]=Latte
Name[fi]=Latte
Name[fr]=Latte
Name[gl]=Latte
Name[id]=Latte
Name[it]=Latte
Name[ko]=Latte
Name[lt]=Latte
Name[nl]=Latte
Name[nn]=Latte
Name[pl]=Latte
Name[pt]=Latte
Name[pt_BR]=Latte
Name[ru]=Latte
Name[sk]=Latte
Name[sl]=Latte
Name[sv]=Latte
Name[uk]=Латте
Name[x-test]=xxLattexx
Name[zh_CN]=Latte
Name[zh_TW]=Latte
Comment=Dock for the masses
Comment[az]=Hər kəs üçün Dok panel
Comment[ca]=Acoblador per a les masses
Comment[ca@valencia]=Acoblador per a les masses
Comment[cs]=Dok pro masy
Comment[da]=Dok til masserene
Comment[de]=Dock für die Massen
Comment[el]=Διαχειριστής εργασιών για όλον τον κόσμο
Comment[en_GB]=Dock for the masses
Comment[es]=Un dock para las masas
Comment[et]=Dokk massidele
Comment[eu]=Jendartearen kaia
Comment[fi]=Telakka massoille
Comment[fr]=Une barre des tâches pour tout le monde
Comment[gl]=Doca para as masas.
Comment[id]=Dock untuk mengumpulkan
Comment[it]=Area di aggancio per le masse
Comment[ko]=모두를 위한 독
Comment[lt]=Dokas masėms
Comment[nl]=Dock voor de massa
Comment[nn]=Dokk for massane
Comment[pl]=Dok dla mas
Comment[pt]=Área acoplável para as massas
Comment[pt_BR]=Área acoplável para todos
Comment[ru]=Док для всех
Comment[sk]=Dok pre davy ľudí
Comment[sl]=Dok za množice
Comment[sv]=Dockningsfönster för alla
Comment[uk]=Панель для усіх
Comment[x-test]=xxDock for the massesxx
Comment[zh_CN]=给大众使用的停靠栏
Comment[zh_TW]=給大眾使用的 Dock
GenericName=Dock
GenericName[az]=Dok
GenericName[ca]=Acobla
GenericName[ca@valencia]=Acobla
GenericName[cs]=Dok
GenericName[da]=Dok
GenericName[de]=Dock
GenericName[el]=Dock
GenericName[en_GB]=Dock
GenericName[es]=Dock
GenericName[et]=Dokk
GenericName[eu]=Kaia
GenericName[fi]=Telakka
GenericName[fr]=Barre des tâches
GenericName[gl]=Doca
GenericName[ia]=Bassino
GenericName[id]=Dok
GenericName[it]=Aggancio
GenericName[ko]=독
GenericName[lt]=Dokas
GenericName[nl]=Dock
GenericName[nn]=Dokk
GenericName[pl]=Dok
GenericName[pt]=Área Acoplável
GenericName[pt_BR]=Área acoplável
GenericName[ru]=Док
GenericName[sk]=Dok
GenericName[sl]=Dok
GenericName[sv]=Dockningsfönster
GenericName[uk]=Панель
GenericName[x-test]=xxDockxx
GenericName[zh_CN]=停靠栏
GenericName[zh_TW]=Dock
Icon=latte-dock
Categories=Utility;X-SuSE-DesktopUtility;
Exec=@CMAKE_INSTALL_PREFIX@/bin/latte-dock
InitialPreference=1
StartupNotify=false
Terminal=false
Type=Application
StartupWMClass=latte-dock
X-DBUS-ServiceName=org.kde.lattedock
X-DBUS-StartupType=unique
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
X-KDE-StartupNotify=false
X-KDE-SubstituteUID=false
X-KDE-Wayland-Interfaces=org_kde_plasma_window_management,org_kde_kwin_keystate,zkde_screencast_unstable_v1
